======
Export
======

Export Series data to other formats:

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

   Series.__arrow_c_stream__
   Series.to_arrow
   Series.to_frame
   Series.to_jax
   Series.to_list
   Series.to_numpy
   Series.to_pandas
   Series.to_init_repr
   Series.to_torch
